# BillingPeriodProductRatePlanChargeRest

The billing period for the charge. The start day of the billing period is also called the bill cycle day (BCD). 

## Enum

* `MONTH` (value: `'Month'`)

* `QUARTER` (value: `'Quarter'`)

* `ANNUAL` (value: `'Annual'`)

* `SEMI_MINUS_ANNUAL` (value: `'Semi-Annual'`)

* `SPECIFIC_MONTHS` (value: `'Specific Months'`)

* `SUBSCRIPTION_TERM` (value: `'Subscription Term'`)

* `WEEK` (value: `'Week'`)

* `SPECIFIC_WEEKS` (value: `'Specific Weeks'`)

* `SPECIFIC_DAYS` (value: `'Specific Days'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


